@@ -1,5 +1,7 @@
 import warnings
 
+from skrt.better_viewer import BetterViewer
+from skrt.better_viewer.options import set_viewer_options
 from skrt.image import Image
 from skrt.dose import Dose
 from skrt.structures import ROI, StructureSet
